﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.Devices.Enumeration;
using Windows.Devices.I2c;
using System.Diagnostics;
using System.Threading;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace MidProject
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private I2cDevice Device;
        private Timer periodicTimer;
        private int sampleFrequency = 10; // 1 second

        List<int> disList = new List<int> ();

        public MainPage()
        {
            this.InitializeComponent();
            SetupI2C();
        }

        private async void SetupI2C()
        {
            var settings = new I2cConnectionSettings(0x40); // Arduino address
            settings.BusSpeed = I2cBusSpeed.StandardMode;
            string aqs = I2cDevice.GetDeviceSelector("I2C1");
            var dis = await DeviceInformation.FindAllAsync(aqs);
            Device = await I2cDevice.FromIdAsync(dis[0].Id, settings);
            // Start a timer
            periodicTimer = new Timer(this.TimerGetAndDisplay
                , null, 0, sampleFrequency);
        }

        private void TimerGetAndDisplay(object state)
        {

            byte[] RegAddrBuf = new byte[] { 0x40 }; // Arduino address
            byte[] ReadBuf = new byte[6];

            try
            {
                Device.Read(ReadBuf); // read the data
            }
            catch (Exception f)
            {
                Debug.WriteLine(f.Message);
            }
            // Decodes a sequence of bytes from the specified byte array into a string

            char[] disArray = System.Text.Encoding.UTF8.GetString(ReadBuf, 0, 2).ToCharArray();
            char[] adcArray = System.Text.Encoding.UTF8.GetString(ReadBuf, 2, 3).ToCharArray();

            // Convert the distance array into a string.
            String dis = new String(disArray);
            string distance = dis.Substring(0, 2);
            Debug.WriteLine("Distance: " + distance + "cm");


            // Convert the ADC array into a string.
            String adc = new String(adcArray);
            string adcvalue = adc.Substring(0, 3);
            Debug.WriteLine("ADC: " + adcvalue);

            // refresh the screen, note Im using a textbock @ UI
            var task = this.Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal, () =>
            { RadialDistance.Value = Convert.ToDouble(distance);
              RadialADC.Value = Convert.ToDouble(adcvalue);
            });

        }

        private void distanceBlock_SelectionChanged(object sender, RoutedEventArgs e)
        {

        }

        private void textBlock_SelectionChanged(object sender, RoutedEventArgs e)
        {

        }
    }
}
